==> sdx-2.2.2-src.zip: sdx-2.2.2/src/java/fr/gouv/culture/sdx/search/lucene/query/RemoteIndex.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.search.lucene.query;

import fr.gouv.culture.sdx.exception.SDXException;
import fr.gouv.culture.sdx.search.lucene.Field;
import fr.gouv.culture.sdx.search.lucene.queryparser.QueryParser;
import org.apache.lucene.search.RemoteSearchable;
import org.apache.lucene.search.Searchable;

import java.io.IOException;
import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;

public class RemoteIndex extends UnicastRemoteObject implements Index {
    /** Constructs and exports a remote index. */
    LuceneIndex lIndex = null;

    public RemoteIndex(LuceneIndex lIndex) throws RemoteException {
        super();
        this.lIndex = lIndex;
    }

    public Searchable getSearcher() throws IOException, SDXException {
        return new RemoteSearchable(lIndex.getSearcher());
    }

    public Field getField(String name) {
        return lIndex.getField(name);
    }

    public Field getDefaultField() {
        return lIndex.getDefaultField();
    }

    public QueryParser getQueryParser() throws IOException, SDXException {
        //query parser is not serializable so we return null always
        return null;
    }

}

==> sdx-2.4-src.zip: sdx-2.4/src/java/fr/gouv/culture/sdx/search/lucene/query/RemoteIndex.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.search.lucene.query;

import fr.gouv.culture.sdx.exception.SDXException;
import fr.gouv.culture.sdx.search.lucene.Field;
import fr.gouv.culture.sdx.search.lucene.queryparser.QueryParser;
//import fr.gouv.culture.sdx.utils.save.SaveParameters;
//import fr.gouv.culture.sdx.utils.save.Saveable;

import org.apache.lucene.search.RemoteSearchable;
import org.apache.lucene.search.Searchable;

import java.io.IOException;
import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;

public class RemoteIndex extends UnicastRemoteObject implements Index {
    /** Constructs and exports a remote index. */
    LuceneIndex lIndex = null;

    public RemoteIndex(LuceneIndex lIndex) throws RemoteException {
        super();
        this.lIndex = lIndex;
    }

    public Searchable getSearcher() throws IOException, SDXException {
        return new RemoteSearchable(lIndex.getSearcher());
    }

    public Field getField(String name) {
        return lIndex.getField(name);
    }

    public Field getDefaultField() {
        return lIndex.getDefaultField();
    }

    public QueryParser getQueryParser() throws IOException, SDXException {
        //query parser is not serializable so we return null always
        return null;
    }

    protected String getClassNameSuffix() {
        return Index.CLASS_NAME_SUFFIX;
    }

}
